searchData={"items":[{"type":"module","title":"Discovergy","doc":"A client for the [Discovergy REST API](https://api.discovergy.com/docs/), providing access to\nmeters and measurements.","ref":"Discovergy.html"},{"type":"module","title":"Usage - Discovergy","doc":"Create a `Discovergy.Client` and authenticate with the Discovergy API using your email address and password.\n\n    iex> {:ok, client} = Discovergy.Client.new() |> Discovergy.Client.login(email, password)\n    {:ok, %Discovergy.Client{}}\n\nThen pass the `client` to the respective endpoint function. For example, to list all meters the user has access to:\n\n    iex> Discovergy.Metadata.get_meters(client)\n    {:ok, [%Discovergy.Meter{\n      administration_number: \"\",\n      current_scaling_factor: 1,\n      first_measurement_time: 1563286659367,\n      full_serial_number: \"1ESY1161229886\",\n      internal_meters: 1,\n      last_measurement_time: 1593949473598,\n      load_profile_type: \"SLP\",\n      location: %Discovergy.Location{\n      city: \"Greven\",\n       country: \"DE\",\n       street: \"Sedanstr.\",\n       street_number: \"8\",\n       zip: \"48268\"\n      },\n      manufacturer_id: \"ESY\",\n      measurement_type: \"ELECTRICITY\",\n      meter_id: \"c1972a89ce3a4d58aadcb7908a1d31c7\",\n      scaling_factor: 1,\n      serial_number: \"61229886\",\n      type: \"EASYMETER\",\n      voltage_scaling_factor: 1\n    }]}\n\nOr to obtain the last measurement of a particular meter:\n\n    iex> Discovergy.Measurements.get_last_reading(client, \"c1972a89ce3a4d58aadcb7908a1d31c7\")\n    {:ok, %Discovergy.Measurement{\n      time: ~U[2019-07-16 22:00:00.000Z],\n      values: %{\n        \"energy\" => 441576730000,\n        \"energyOut\" => 2154853000,\n        \"power\" => 205980,\n        \"power1\" => 63090,\n        \"power2\" => 53780,\n        \"power3\" => 89100,\n        \"voltage1\" => 234100,\n        \"voltage2\" => 234000,\n        \"voltage3\" => 233800\n      }\n    }}","ref":"Discovergy.html#module-usage"},{"type":"module","title":"Configuration - Discovergy","doc":"The main way to configure Discovergy is through the options passed to `Discovergy.Client.new/1`.\n\nTo customize the behaviour of the HTTP client used by Discovergy, you can configure Discovergy\nthrough the application environment . For example, you can do this in `config/runtime.exs`:\n\n    # config/runtime.exs\n    config :discovergy,\n      # ...\n\nYou can use these options:\n\n- `:client` (`t:module/0`) - A module that implements the `Discovergy.HTTPClient` behaviour.\n  Defaults to `Discovergy.HTTPClient.Finch` (requires `:finch`).\n\n- `:client_pool_opts` (`t:keyword/0`) - Options to configure the HTTP client pool. See\n  `Finch.start_link/1`. Defaults to `[]`.\n\n- `:client_request_opts` (`t:keyword/0`) - Options passed to the\n  `c:Discovergy.HTTPClient.request/5` callback. See `Finch.request/3`. Defaults to `[]`.","ref":"Discovergy.html#module-configuration"},{"type":"module","title":"Discovergy.Client","doc":"A Discovergy API Client","ref":"Discovergy.Client.html"},{"type":"function","title":"Discovergy.Client.login/3","doc":"Authenticate with the Discovergy API using the email address and password of\nthe user.","ref":"Discovergy.Client.html#login/3"},{"type":"function","title":"Examples - Discovergy.Client.login/3","doc":"iex> {:ok, client} = Discovergy.Client.new()\n    ...>                 |> Discovergy.Client.login(email, password)\n    {:ok, %Discovergy.Client{}}","ref":"Discovergy.Client.html#login/3-examples"},{"type":"function","title":"Discovergy.Client.new/1","doc":"Creates a new Discovergy API client.","ref":"Discovergy.Client.html#new/1"},{"type":"function","title":"Options - Discovergy.Client.new/1","doc":"- `:base_url` - the base URL for all endpoints (default: `https://api.discovergy.com/public/v1`)","ref":"Discovergy.Client.html#new/1-options"},{"type":"function","title":"Examples - Discovergy.Client.new/1","doc":"iex> client = Discovergy.Client.new()\n    %Discovergy.Client{}","ref":"Discovergy.Client.html#new/1-examples"},{"type":"opaque","title":"Discovergy.Client.t/0","doc":"","ref":"Discovergy.Client.html#t:t/0"},{"type":"behaviour","title":"Discovergy.HTTPClient","doc":"Specifies the API for using a custom HTTP Client.\n\nThe default HTTP client is `Discovergy.HTTPClient.Finch`.\n\nTo configure a different HTTP client, implement the `Discovergy.HTTPClient` behaviour\nand change the `:client` configuration:\n\n    config :discovergy, client: MyHTTPClient","ref":"Discovergy.HTTPClient.html"},{"type":"behaviour","title":"Example - Discovergy.HTTPClient","doc":"A client implementation based on `:hackney` could look like this:\n\n    defmodule MyHTTPClient do\n      @behaviour Discovergy.HTTPClient\n\n      @hackney_pool_name :discovergy_pool\n\n      @impl true\n      def child_spec(opts) do\n        :hackney_pool.child_spec(@hackney_pool_name, opts)\n      end\n\n      @impl true\n      def request(method, url, headers, body, opts) do\n        opts = Keyword.merge(opts, pool: @hackney_pool_name) ++ [:with_body]\n\n        case :hackney.request(method, url, headers, body, opts) do\n          {:ok, _status, _headers, _body} = result -> result\n          {:error, _reason} = error -> error\n        end\n      end\n    end","ref":"Discovergy.HTTPClient.html#module-example"},{"type":"callback","title":"Discovergy.HTTPClient.child_spec/1","doc":"Should return a **child specification** to start the HTTP client or `nil`.\n\nFor example, this can start a pool of HTTP connections dedicated to Discovergy.","ref":"Discovergy.HTTPClient.html#c:child_spec/1"},{"type":"callback","title":"Discovergy.HTTPClient.request/5","doc":"Should make an HTTP request to `url` with the given `method`, `headers`, `body` and `req_opts`.","ref":"Discovergy.HTTPClient.html#c:request/5"},{"type":"type","title":"Discovergy.HTTPClient.body/0","doc":"HTTP request or response body.","ref":"Discovergy.HTTPClient.html#t:body/0"},{"type":"type","title":"Discovergy.HTTPClient.headers/0","doc":"HTTP request or response headers.","ref":"Discovergy.HTTPClient.html#t:headers/0"},{"type":"type","title":"Discovergy.HTTPClient.method/0","doc":"HTTP request method.","ref":"Discovergy.HTTPClient.html#t:method/0"},{"type":"type","title":"Discovergy.HTTPClient.pool_opts/0","doc":"Options to configure the pool (set via `:client_pool_opts`).","ref":"Discovergy.HTTPClient.html#t:pool_opts/0"},{"type":"type","title":"Discovergy.HTTPClient.req_opts/0","doc":"HTTP request options (set via `:client_request_opts`).","ref":"Discovergy.HTTPClient.html#t:req_opts/0"},{"type":"type","title":"Discovergy.HTTPClient.status/0","doc":"HTTP response status.","ref":"Discovergy.HTTPClient.html#t:status/0"},{"type":"type","title":"Discovergy.HTTPClient.url/0","doc":"HTTP request URL.","ref":"Discovergy.HTTPClient.html#t:url/0"},{"type":"module","title":"Discovergy.HTTPClient.Finch","doc":"The built-in HTTP client, based on [finch](https://github.com/sneako/finch).\n\nIt client implements the `Discovergy.HTTPClient` behaviour.\n\nSee `Discovergy` for the available configuration options and `Discovergy.HTTPClient` if you wish\nto use another HTTP client.","ref":"Discovergy.HTTPClient.Finch.html"},{"type":"module","title":"Discovergy.Disaggregation","doc":"The Disaggregation endpoint","ref":"Discovergy.Disaggregation.html"},{"type":"function","title":"Discovergy.Disaggregation.get_activities/4","doc":"Returns the activities recognised for the given meter during the given\ninterval.","ref":"Discovergy.Disaggregation.html#get_activities/4"},{"type":"function","title":"Examples - Discovergy.Disaggregation.get_activities/4","doc":"iex> Discovergy.Measurements.get_activities(client, meter_id, from, to)\n    {:ok, [\n      %Discovergy.DisaggregationActivity{\n        activity_id: 77,\n        begin_time: ~U[2019-07-16 02:13:24.000Z],\n        end_time: ~U[2019-07-16 22:00:00.000Z],\n        device_id: 1,\n        device_name: \"BASE_LOAD-1\",\n        device_type: \"BASE_LOAD\",\n        energy: 16414633333\n      },\n      ...\n    ]}","ref":"Discovergy.Disaggregation.html#get_activities/4-examples"},{"type":"function","title":"Discovergy.Disaggregation.get_energy_by_device_measurements/4","doc":"Provides the disaggregated energy for the specified meter at 15 minute\nintervals.","ref":"Discovergy.Disaggregation.html#get_energy_by_device_measurements/4"},{"type":"function","title":"Examples - Discovergy.Disaggregation.get_energy_by_device_measurements/4","doc":"iex> Discovergy.Disaggregation.get_energy_by_device_measurements(\n    ...>  client, meter_id, from\n    ...> )\n    {:ok, [\n      %Discovergy.EnergyByDeviceMeasurement{\n        time: ~U[2020-07-01 22:15:00.000Z],\n        energy_by_device: %{\n          \"Backofen-1\" => 0,\n          \"Backofen-2\" => 0,\n          \"Durchlauferhitzer-1\" => 0,\n          \"Durchlauferhitzer-2\" => 0,\n          \"Durchlauferhitzer-3\" => 0,\n          \"Elektromobilität-1\" => 0,\n          \"Grundlast-1\" => 232500000,\n          \"Kühlschrank-1\" => 1433333,\n          \"Kühlschrank-2\" => 0,\n          \"Kühlschrank-3\" => 0,\n          \"Spülmaschine-1\" => 0,\n          \"Waschmaschine-1\" => 0\n        }\n      },\n      ...\n    ]}","ref":"Discovergy.Disaggregation.html#get_energy_by_device_measurements/4-examples"},{"type":"module","title":"Discovergy.Measurements","doc":"The Measurements endpoint","ref":"Discovergy.Measurements.html"},{"type":"function","title":"Discovergy.Measurements.get_last_reading/3","doc":"Return the last measurement for the specified meter.","ref":"Discovergy.Measurements.html#get_last_reading/3"},{"type":"function","title":"Options - Discovergy.Measurements.get_last_reading/3","doc":"* `:fields` - list of measurement fields to return in the result (use\n  `Discovergy.Metadata.get_field_names/2` to get all available fields)\n  * `:each` - Return data from the virtual meter itself (false) or all its\n  sub-meters (true). Only applies if meterId refers to a virtual meter","ref":"Discovergy.Measurements.html#get_last_reading/3-options"},{"type":"function","title":"Examples - Discovergy.Measurements.get_last_reading/3","doc":"iex> Discovergy.Measurements.get_last_reading(client, meter_id)\n    {:ok, %Discovergy.Measurement{\n      time: ~U[2019-07-16 22:00:00.000Z],\n      values: %{\n        \"energy\" => 441576730000,\n        \"energyOut\" => 2154853000,\n        \"power\" => 205980,\n        \"power1\" => 63090,\n        \"power2\" => 53780,\n        \"power3\" => 89100,\n        \"voltage1\" => 234100,\n        \"voltage2\" => 234000,\n        \"voltage3\" => 233800\n      }\n    }}","ref":"Discovergy.Measurements.html#get_last_reading/3-examples"},{"type":"function","title":"Discovergy.Measurements.get_load_profile/5","doc":"Return load profile for the given meter.","ref":"Discovergy.Measurements.html#get_load_profile/5"},{"type":"function","title":"Options - Discovergy.Measurements.get_load_profile/5","doc":"* `:resolution` - reading resolution. Possible values: `:raw`, `:one_day`,\n  `:one_month`, `:one_year`","ref":"Discovergy.Measurements.html#get_load_profile/5-options"},{"type":"function","title":"Examples - Discovergy.Measurements.get_load_profile/5","doc":"iex> Discovergy.Measurements.get_load_profile(client, meter_id,\n    ...>                                              ~D{2020-07-01},\n    ...>                                              ~D{2020-07-01},\n    ...>                                              resolution: :one_day)\n    {:ok, [\n      %{\n        \"1.29\" => 0.816,\n        \"2.29\" => 833.028,\n        \"3.29\" => 179.376,\n        \"4.29\" => 16.128,\n        \"5.29\" => 9.06,\n        \"6.29\" => 170.328,\n        \"7.29\" => 12.744,\n        \"8.29\" => 3.384,\n        \"status\" => 0,\n        \"time\" => 1593640800000\n      },\n      %{\"1.6.0\" => 0.96, \"time\" => 1593585000000},\n      %{\"2.6.0\" => 142.44, \"time\" => 1593601200000}\n    ]}","ref":"Discovergy.Measurements.html#get_load_profile/5-examples"},{"type":"function","title":"Discovergy.Measurements.get_raw_load_profile/3","doc":"Return the raw, unmodified load profile file as sent by the specified RLM\nmeter on the specified date.","ref":"Discovergy.Measurements.html#get_raw_load_profile/3"},{"type":"function","title":"Examples - Discovergy.Measurements.get_raw_load_profile/3","doc":"iex> {:ok,  >} =\n    ...>   Discovergy.Measurements.get_raw_load_profile(client, meter_id, ~D{2020-07-01})\n    {:ok,  >}\n\n    iex> String.split(profile)\n    [\"P.01(1200701001500)(00000000)(15)(8)(1.29)(kWh)(2.29)(kWh)(3.29)(kvarh)(4.29)...\",\n     \"(0.0001)(0.0000)(0.0000)(0.0032)(0.0000)(0.0000)(0.0026)(0.0007)\",\n     \"(0.0000)(0.0000)(0.0000)(0.0035)(0.0000)(0.0000)(0.0029)(0.0005)\",\n     \"(0.0000)(0.0001)(0.0000)(0.0036)(0.0000)(0.0000)(0.0030)(0.0006)\",","ref":"Discovergy.Measurements.html#get_raw_load_profile/3-examples"},{"type":"function","title":"Discovergy.Measurements.get_readings/5","doc":"Return the measurements for the specified meter in the specified time interval.","ref":"Discovergy.Measurements.html#get_readings/5"},{"type":"function","title":"Options - Discovergy.Measurements.get_readings/5","doc":"* `:fields` - list of measurement fields to return in the result (use\n  `Discovergy.Metadata.get_field_names/2` to get all available fields)\n  * `:resolution` - time distance between returned readings. Possible values:\n  `:raw` (default), `:three_minutes`, `:fifteen_minutes`, `:one_hour`, `:one_day`,\n  `:one_week`, `:one_month`, `:one_year`\n  * `: disaggregation ` - Include load disaggregation as pseudo-measurement\n  fields, if available. Only applies if raw resolution is selected\n  * `:each` - Return data from the virtual meter itself (false) or all its\n  sub-meters (true). Only applies if meterId refers to a virtual meter","ref":"Discovergy.Measurements.html#get_readings/5-options"},{"type":"function","title":"Examples - Discovergy.Measurements.get_readings/5","doc":"iex> Discovergy.Measurements.get_readings(client, meter_id, from, to,\n    ...>                                  resolution: :one_month)\n    {:ok, [\n     %Discovergy.Measurement{\n       time: ~U[2019-07-16 22:00:00.000Z],\n       values: %{\n         \"energy\" => 8069238602135,\n         \"energy1\" => 0,\n         \"energy2\" => 0,\n         \"energyOut\" => 2033461000,\n         \"energyOut1\" => 0,\n         \"energyOut2\" => 0,\n         \"power\" => 512286,\n         \"power1\" => 189978,\n         \"power2\" => 129660,\n         \"power3\" => 192654,\n         \"voltage1\" => 230469,\n         \"voltage2\" => 231599,\n         \"voltage3\" => 230247\n       }\n     },\n     ...\n    ]}","ref":"Discovergy.Measurements.html#get_readings/5-examples"},{"type":"function","title":"Discovergy.Measurements.get_statistics/5","doc":"Return various statistics calculated over all measurements for the specified\nmeter in the specified time interval.","ref":"Discovergy.Measurements.html#get_statistics/5"},{"type":"function","title":"Options - Discovergy.Measurements.get_statistics/5","doc":"* `:fields` - list of measurement fields to return in the result (use\n  `Discovergy.Metadata.get_field_names/2` to get all available fields)","ref":"Discovergy.Measurements.html#get_statistics/5-options"},{"type":"function","title":"Examples - Discovergy.Measurements.get_statistics/5","doc":"iex> Discovergy.Measurements.get_statistics(client, meter_id, from)\n    {:ok, %{\n      \"energy\" => %{\n        \"count\" => 53962,\n        \"maximum\" => 441687910000,\n        \"mean\" => 420770138841.7405,\n        \"minimum\" => 402102161000,\n        \"variance\" => 1.430940674699829e20\n      },\n      \"energyOut\" => %{\n        ...\n      },\n      \"power\" => %{\n        ...\n      },\n      \"power1\" => %{\n        ...\n      },\n      \"power2\" => %{\n        ...\n      },\n      \"power3\" => %{\n        ...\n      },\n      \"voltage1\" => %{\n        ...\n      },\n      \"voltage2\" => %{\n        ...\n      },\n      \"voltage3\" => %{\n        ...\n      }\n    }}","ref":"Discovergy.Measurements.html#get_statistics/5-examples"},{"type":"module","title":"Discovergy.Metadata","doc":"The Metadata endpoint","ref":"Discovergy.Metadata.html"},{"type":"function","title":"Discovergy.Metadata.get_devices/2","doc":"Returns the devices recognised for the given meter.","ref":"Discovergy.Metadata.html#get_devices/2"},{"type":"function","title":"Examples - Discovergy.Metadata.get_devices/2","doc":"iex> Discovergy.Metadata.get_devices(client, meter_id)\n    {:ok, [\"BASE_LOAD-1\", \"DISHWASHER-1\", \"ELECTRIC_VEHICLE-1\", \"OVEN-1\", \"OVEN-2\",\n    \"REFRIGERATOR-1\", \"REFRIGERATOR-2\", \"REFRIGERATOR-3\", \"WASHING_MACHINE-1\",\n    \"WATER_HEATER-1\", \"WATER_HEATER-2\", \"WATER_HEATER-3\"]}","ref":"Discovergy.Metadata.html#get_devices/2-examples"},{"type":"function","title":"Discovergy.Metadata.get_field_names/2","doc":"Return the available measurement field names for the specified meter.","ref":"Discovergy.Metadata.html#get_field_names/2"},{"type":"function","title":"Examples - Discovergy.Metadata.get_field_names/2","doc":"iex> Discovergy.Metadata.get_field_names(client, meter_id)\n    {:ok, [\"energy\", \"energy1\", \"energy2\", \"energyOut\", \"energyOut1\", \"energyOut2\",\n    \"power\", \"power1\", \"power2\", \"power3\", \"voltage1\", \"voltage2\", \"voltage3\"]}","ref":"Discovergy.Metadata.html#get_field_names/2-examples"},{"type":"function","title":"Discovergy.Metadata.get_meters/1","doc":"Return all meters that the user has access to.","ref":"Discovergy.Metadata.html#get_meters/1"},{"type":"function","title":"Examples - Discovergy.Metadata.get_meters/1","doc":"iex> {:ok, meters} = Discovergy.Metadata.get_meters(client)\n    {:ok, [%Discovergy.Meter{\n       meter_id: \"c1972a89ce3a4d58aadcb7908a1d31c7\",\n       serial_number: \"61229886\",\n       full_serial_number: \"1ESY1161229886\",\n       location: %Discovergy.Location{\n         city: \"Greven\",\n         country: \"DE\",\n         street: \"Sedanstr.\",\n         street_number: \"8\",\n         zip: \"48268\"\n       },\n       administration_number: \"\",\n       type: \"EASYMETER\",\n       manufacturer_id: \"ESY\",\n       measurement_type: \"ELECTRICITY\",\n       scaling_factor: 1,\n       current_scaling_factor: 1,\n       voltage_scaling_factor: 1,\n       internal_meters: 1,\n       first_measurement_time: 1563286659367,\n       last_measurement_time: 1593952103706,\n       load_profile_type: \"SLP\"\n    }]}","ref":"Discovergy.Metadata.html#get_meters/1-examples"},{"type":"module","title":"Discovergy.VirtualMeters","doc":"The Virtual Meters endpoint","ref":"Discovergy.VirtualMeters.html"},{"type":"function","title":"Discovergy.VirtualMeters.create_virtual_meter/3","doc":"Return the individual meters comprising the specified virtual meter.","ref":"Discovergy.VirtualMeters.html#create_virtual_meter/3"},{"type":"function","title":"Discovergy.VirtualMeters.get_virtual_meter/2","doc":"Return the individual meters comprising the specified virtual meter.","ref":"Discovergy.VirtualMeters.html#get_virtual_meter/2"},{"type":"module","title":"Discovergy.WebsiteAccessCode","doc":"The Webste Access Code endpoint","ref":"Discovergy.WebsiteAccessCode.html"},{"type":"function","title":"Discovergy.WebsiteAccessCode.generate/2","doc":"Generates an access code that can be used to login a user into the Discovery\nPortal without the need of a password. This is useful e.g. to embed the\nDiscovergy portal as an iframe into the partner's portal.\n\nThe access code is only valid if the user to be logged in is the same user\ncurrently using the API or if the user currently using the API is the partner\nof the user to be logged in. The latter option to access the user of a\npartner is only available if enabled by Discovergy for a specific partner,\nplease write to technical support if you need access. Please also note that\nthe code returned is only valid for **3 hours**, so it should not be cached\nbut requested every time it is needed. When you received an access token, the\nportal can be accessed using the URL\n[https://my.discovergy.com/?email=user@example.org&code=abc123](https://my.discovergy.com/?email=user@example.org&code=abc123)\n(please replace `user@example.org` by the user name you want to login and\n`abc123` by the access code you retrieved). This URL can be used as the src\nfor an iframe in order to embed it into an existing web application.","ref":"Discovergy.WebsiteAccessCode.html#generate/2"},{"type":"function","title":"Examples - Discovergy.WebsiteAccessCode.generate/2","doc":"iex> Discovergy.WebsiteAccessCode.generate(client, email)\n    {:ok, \"2020060515c15010e31f803ed6f578efab3381c177db15e152f94be015bd938\"}","ref":"Discovergy.WebsiteAccessCode.html#generate/2-examples"},{"type":"module","title":"Discovergy.DisaggregationActivity","doc":"","ref":"Discovergy.DisaggregationActivity.html"},{"type":"type","title":"Discovergy.DisaggregationActivity.t/0","doc":"","ref":"Discovergy.DisaggregationActivity.html#t:t/0"},{"type":"module","title":"Discovergy.EnergyByDeviceMeasurement","doc":"","ref":"Discovergy.EnergyByDeviceMeasurement.html"},{"type":"type","title":"Discovergy.EnergyByDeviceMeasurement.t/0","doc":"","ref":"Discovergy.EnergyByDeviceMeasurement.html#t:t/0"},{"type":"module","title":"Discovergy.Location","doc":"","ref":"Discovergy.Location.html"},{"type":"type","title":"Discovergy.Location.t/0","doc":"","ref":"Discovergy.Location.html#t:t/0"},{"type":"module","title":"Discovergy.Measurement","doc":"","ref":"Discovergy.Measurement.html"},{"type":"type","title":"Discovergy.Measurement.t/0","doc":"","ref":"Discovergy.Measurement.html#t:t/0"},{"type":"module","title":"Discovergy.Meter","doc":"","ref":"Discovergy.Meter.html"},{"type":"type","title":"Discovergy.Meter.id/0","doc":"","ref":"Discovergy.Meter.html#t:id/0"},{"type":"type","title":"Discovergy.Meter.t/0","doc":"","ref":"Discovergy.Meter.html#t:t/0"},{"type":"exception","title":"Discovergy.Error","doc":"A Discovergy Error","ref":"Discovergy.Error.html"},{"type":"type","title":"Discovergy.Error.t/0","doc":"","ref":"Discovergy.Error.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.6.0 (2023-08-26) - Changelog","doc":"#","ref":"changelog.html#v0-6-0-2023-08-26"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Migrate built-in HTTP from `hackney` to `Finch`\n- Replace the`:adapter` with the `:client` option\n- `Discovergy.Error`: Replace the `:env` field with `:response`\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Upgrade instructions - Changelog","doc":"##","ref":"changelog.html#upgrade-instructions"},{"type":"extras","title":"Dependencies - Changelog","doc":"Discovergy now ships with an HTTP client based on `:finch` instead of `:hackney`.\n\nAdd `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:discovergy, \"~> 0.6\"},\n    {:finch, \"~> 0.16\"},\n  ]\nend\n```\n\n##","ref":"changelog.html#dependencies"},{"type":"extras","title":"HTTP client (optional) - Changelog","doc":"1. Remove the `:adapter` configuration from `Discovergy.Client.new/1`:\n\n   ```diff\n   {:ok, client} = Discovergy.Client.new(\n   -  adapter: {Tesla.Adapter.Gun, []}\n   )\n   ```\n\n2. In `config/runtime.exs` set the `:discovergy, :client` option and to your own module that implements the `Discovergy.HTTPClient` behaviour:\n\n   ```diff\n   + config :discovergy,\n   +   client: MyGunAdapter\n   ```\n\nSee the documentation for `Discovergy.HTTPClient` for more information.","ref":"changelog.html#http-client-optional"},{"type":"extras","title":"v0.5.0 (2021-10-27) - Changelog","doc":"- Do not reuse consumer token when logging in","ref":"changelog.html#v0-5-0-2021-10-27"},{"type":"extras","title":"v0.4.0 (2020-07-13) - Changelog","doc":"- Make `hackney` an optional dependency","ref":"changelog.html#v0-4-0-2020-07-13"},{"type":"extras","title":"v0.3.0 (2020-07-11) - Changelog","doc":"- Reuse consumer when logging in","ref":"changelog.html#v0-3-0-2020-07-11"},{"type":"extras","title":"v0.2.0 (2020-07-07) - Changelog","doc":"- Create a common struct for request & access tokens (`Discovergy.OAuth.Token`)\n- Update docs and add usage examples","ref":"changelog.html#v0-2-0-2020-07-07"},{"type":"extras","title":"v0.1.0 (2020-07-07) - Changelog","doc":"- Initial Release","ref":"changelog.html#v0-1-0-2020-07-07"},{"type":"extras","title":"Discovergy","doc":"# Discovergy\n\n[![Build Status](https://github.com/adriankumpf/discovergy/workflows/CI/badge.svg)](https://github.com/adriankumpf/discovergy/actions)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg?style=flat)](https://hexdocs.pm/discovergy)\n[![Hex.pm](https://img.shields.io/hexpm/v/discovergy?color=%23714a94)](http://hex.pm/packages/discovergy)\n\n> A client for the [Discovergy REST API](https://api.discovergy.com/docs/), providing access to meters and measurements.","ref":"readme.html"},{"type":"extras","title":"Installation - Discovergy","doc":"Add `:discovergy` and `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:discovergy, \"~> 0.6\"},\n    {:finch, \"~> 0.16\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Discovergy","doc":"Create a `Discovergy.Client` and authenticate with the Discovergy API using your email address and password.\n\n```elixir\niex> {:ok, client} = Discovergy.Client.new() |> Discovergy.Client.login(email, password)\n{:ok, %Discovergy.Client{}}\n```\n\nThen pass the `client` to the respective endpoint function. For example, to list all meters the user has access to:\n\n```elixir\niex> Discovergy.Metadata.get_meters(client)\n{:ok, [%Discovergy.Meter{\n  administration_number: \"\",\n  current_scaling_factor: 1,\n  first_measurement_time: 1563286659367,\n  full_serial_number: \"1ESY1161229886\",\n  internal_meters: 1,\n  last_measurement_time: 1593949473598,\n  load_profile_type: \"SLP\",\n  location: %Discovergy.Location{\n  city: \"Greven\",\n   country: \"DE\",\n   street: \"Sedanstr.\",\n   street_number: \"8\",\n   zip: \"48268\"\n  },\n  manufacturer_id: \"ESY\",\n  measurement_type: \"ELECTRICITY\",\n  meter_id: \"c1972a89ce3a4d58aadcb7908a1d31c7\",\n  scaling_factor: 1,\n  serial_number: \"61229886\",\n  type: \"EASYMETER\",\n  voltage_scaling_factor: 1\n}]}\n```\n\nOr to obtain the last measurement of a particular meter:\n\n```elixir\niex> Discovergy.Measurements.get_last_reading(client, \"c1972a89ce3a4d58aadcb7908a1d31c7\")\n{:ok, %Discovergy.Measurement{\n  time: ~U[2019-07-16 22:00:00.000Z],\n  values: %{\n    \"energy\" => 441576730000,\n    \"energyOut\" => 2154853000,\n    \"power\" => 205980,\n    \"power1\" => 63090,\n    \"power2\" => 53780,\n    \"power3\" => 89100,\n    \"voltage1\" => 234100,\n    \"voltage2\" => 234000,\n    \"voltage3\" => 233800\n  }\n}}\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - Discovergy","doc":"This project is Licensed under the [MIT License](LICENSE).","ref":"readme.html#license"}],"content_type":"text/markdown"}